@@ -103,7 +103,10 @@ async def train(config: Config, tasks: list[Task]) -> None:
     if is_main_process():
         hud_console.info(f"Creating job with config.job_id: {config.job_id}")
         job_obj = hud.create_job(
-            job_id=config.job_id, name=config.job_name, metadata={"config": config.to_dict()}
+            job_id=config.job_id, name=config.job_name, metadata={
+                "config": config.to_dict(),
+                "agent_class": config.model.base_model
+            }
         )
         hud_console.info(f"Created job with job_obj.id: {job_obj.id}")
         job_obj.update_status_sync("running")
@@ -232,6 +235,9 @@ async def train(config: Config, tasks: list[Task]) -> None:
                     )
                     learner.save(str(checkpoint_path))
 
+                    # Wait for 6 seconds to ensure the checkpoint is saved
+                    await asyncio.sleep(6)
+
                     adapter_name = f"{config.adapter_prefix}-{checkpoint_id}"
                     if vllm.load_adapter(adapter_name, str(checkpoint_path)):
                         actor.update_adapter(adapter_name)
